@@ -37,7 +37,7 @@ use warnings 'once';
 use File::Path 'make_path';
 use Text::Diff;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use App::LXC::Container::Texts;
 use App::LXC::Container::Data;
@@ -438,7 +438,7 @@ sub _create_main_window($)
     # network selection:
     my $title = UI::Various::Text->new(text => txt('network'));
     my $network = UI::Various::Radio->new(buttons => [0 => txt('none'),
-						      1 => txt('local'),
+						      1 => txt('local_'),
 						      2 => txt('full')],
 					  var => \$self->{network});
     my $box_network =  UI::Various::Box->new(border => 1, rows => 2);
