@@ -68,7 +68,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 #########################################################################
 
@@ -163,7 +163,8 @@ our %T =
      => 'INTERNAL ERROR (please contact author): %s',
      link_to_root_missing
      => '$HOME/.lxc-configuration link is missing',
-     local
+     # apparently local is a reserved word in Perl 5.16:
+     local_
      => 'local',
      mandatory_package__1_missing
      => 'mandatory package for %s is missing',
